Format an effect estimate and confidence interval as text
Source:R/geom-forest-text.R
format_effect.RdA small helper for building the label of a geom_forest_text() column,
producing strings such as "1.40 (0.65 to 3.00)".

R/geom-forest-text.R
format_effect.RdA small helper for building the label of a geom_forest_text() column,
producing strings such as "1.40 (0.65 to 3.00)".